--- Source/Core/Common/Src/CDUtils.cpp.orig	2010-03-19 09:41:01.000000000 +0000
+++ Source/Core/Common/Src/CDUtils.cpp	2010-03-25 09:14:07.424216205 +0000
@@ -1,5 +1,11 @@
 // Most of the code in this file was shamelessly ripped from libcdio With minor adjustments
- 
+
+#ifdef __FreeBSD__ 
+#include <fcntl.h>
+#include <sys/types.h>
+#include <sys/stat.h>
+#endif
+
 #include "CDUtils.h"
 #include "Common.h"
   
@@ -353,6 +359,76 @@
 }
 #endif
 
+#ifdef __FreeBSD__
+/* checklist: /dev/acd?, /dev/cd? */
+static struct
+{
+    const char * format;
+    unsigned int num_min;
+    unsigned int num_max;
+} checklist1[] =
+	{
+		{ "/dev/acd%d", 0,   27 },
+		{ "/dev/cd%d",  0,   27 },
+		{ /* End of array */ }
+	};
+
+/*
+  Returns true if a device is a block or char device
+ */
+bool cdio_is_device_quiet_generic(const char *source_name) {
+	struct stat buf;
+	if (0 != stat(source_name, &buf)) {
+		return false;
+	}
+	return (S_ISBLK(buf.st_mode) || S_ISCHR(buf.st_mode));
+}
+
+/*
+  Check a drive to see if it is a CD-ROM 
+   Return 1 if a CD-ROM. 0 if it exists but isn't a CD-ROM drive
+   and -1 if no device exists .
+*/
+static bool is_cdrom_freebsd(const char *drive, char *mnttype) {
+	bool is_cd=false;
+	int cdfd;
+	
+	/* If it doesn't exist, return -1 */
+	if ( !cdio_is_device_quiet_generic(drive) ) {
+		return(false);
+	}
+	
+	/* If it does exist, verify that it's an available CD-ROM */
+	cdfd = open(drive, (O_RDONLY|O_NONBLOCK), 0);
+	if ( cdfd >= 0 ) {
+		is_cd = true;
+		close(cdfd);
+    }
+	return(is_cd);
+}
+
+// Returns a pointer to an array of strings with the device names
+std::vector<std::string> cdio_get_devices_freebsd () {
+	
+	unsigned int i;
+	char drive[40];
+    std::vector<std::string> drives;
+	
+	// Scan the system for CD-ROM drives.
+	for ( i=0; checklist1[i].format; ++i ) {
+		unsigned int j;
+		for ( j=checklist1[i].num_min; j<=checklist1[i].num_max; ++j ) {
+			sprintf(drive, checklist1[i].format, j);
+			if ( (is_cdrom_freebsd(drive, NULL)) > 0 ) {
+                std::string str = drive;
+                drives.push_back(str);
+			}
+		}
+	}
+	return drives;
+}
+#endif
+
 // Returns a pointer to an array of strings with the device names
 std::vector<std::string> cdio_get_devices() {
 #ifdef _WIN32
@@ -361,6 +437,8 @@
 	return cdio_get_devices_osx();
 #elif __linux__
 	return cdio_get_devices_linux();
+#elif __FreeBSD__
+	return cdio_get_devices_freebsd();
 #else
 #warning CDIO not supported on your platform!
 #endif
