--- Source/Core/Common/Src/FileUtil.cpp.orig	2010-03-30 06:09:04.246104742 +0000
+++ Source/Core/Common/Src/FileUtil.cpp	2010-03-30 06:13:02.425982072 +0000
@@ -68,10 +68,18 @@
 // Returns true if file filename exists
 bool Exists(const char *filename)
 {
+#if defined __FreeBSD__
+	struct stat file_info;
+#else
 	struct stat64 file_info;
+#endif
 		
 	char *copy = StripTailDirSlashes(__strdup(filename));
+#if defined __FreeBSD__
+	int result = stat(copy, &file_info);
+#else
 	int result = stat64(copy, &file_info);
+#endif
 	free(copy);
 
 	return (result == 0);
@@ -80,11 +88,19 @@
 // Returns true if filename is a directory
 bool IsDirectory(const char *filename)
 {
+#if defined __FreeBSD__
+	struct stat file_info;
+#else
 	struct stat64 file_info;
+#endif
 
 	char *copy = StripTailDirSlashes(__strdup(filename));
 
+#if defined __FreeBSD__
+	int result = stat(copy, &file_info);
+#else
 	int result = stat64(copy, &file_info);
+#endif
 	free(copy);
 
 	if (result < 0) {
@@ -330,8 +346,13 @@
 		return 0;
 	}
 	// on windows it's actually _stat64 defined in commonFuncs
+#if defined __FreeBSD__
+	struct stat buf;
+	if (stat(filename, &buf) == 0) {
+#else
 	struct stat64 buf;
 	if (stat64(filename, &buf) == 0) {
+#endif
 		DEBUG_LOG(COMMON, "GetSize: %s: %ld", filename, buf.st_size);
 		return buf.st_size;
 	}
